@@ -449,6 +449,7 @@ class CheckAll:
         logger = self.bot.logger
         logger.debug("CheckAll perform-loop start")
         for msg_id in self.db.get_msgs():
+            message = None
             try:
                 message = self.bot.account.get_message_by_id(msg_id)
                 headers = message.get_mime_headers() or dict()
@@ -473,6 +474,8 @@ class CheckAll:
             except Exception as ex:
                 logger.exception("processing message=%s failed: %s", msg_id, ex)
             self.db.pop_msg(msg_id)
+            if message is not None:
+                message.mark_seen()
         logger.debug("CheckAll perform-loop finish")
 
     def handle_system_message(self, message: Message, replies: Replies) -> None:
