@@ -3,13 +3,13 @@ import logging
 import os
 import re
 from tempfile import NamedTemporaryFile
-from typing import Optional
+from typing import List, Optional, Tuple
 from urllib.parse import quote, unquote
 
-from deltachat.message import extract_addr
-from PIL import Image
-from PIL.ImageColor import getcolor, getrgb
-from PIL.ImageOps import grayscale
+from deltachat.message import extract_addr  # type: ignore
+from PIL import Image  # type: ignore
+from PIL.ImageColor import getcolor, getrgb  # type: ignore
+from PIL.ImageOps import grayscale  # type: ignore
 
 # disable Pillow debugging to stdout
 logging.getLogger("PIL").setLevel(logging.ERROR)
@@ -26,7 +26,9 @@ def set_builtin_avatar(bot, name: str = "adaptive-default") -> bool:
     if name.startswith("adaptive-"):
         color = "#" + hex(bot.get_chat(bot.self_contact).get_color())[2:].zfill(6)
         blobdir = bot.account.get_blobdir()
-        with NamedTemporaryFile(dir=blobdir, suffix=ext, delete=False) as fp:
+        with NamedTemporaryFile(
+            dir=blobdir, prefix="avatar-", suffix=ext, delete=False
+        ) as fp:
             result_path = fp.name
         image_tint(path, color).save(result_path)
         path = result_path
@@ -43,14 +45,14 @@ def get_builtin_avatars() -> list:
 
 
 def get_config_folder() -> str:
-    return os.path.join(os.path.expanduser("~"), ".config", "simplebot")
+    return os.path.join(os.path.expanduser("~"), ".simplebot")
 
 
 def get_account_path(address: str) -> str:
     return os.path.join(get_config_folder(), "accounts", quote(address))
 
 
-def get_accounts() -> list:
+def get_accounts() -> List[Tuple[str, str]]:
     accounts_dir = os.path.join(get_config_folder(), "accounts")
     accounts = []
     if os.path.exists(accounts_dir):
@@ -79,7 +81,7 @@ def get_default_account() -> str:
     if not def_account:
         accounts = get_accounts()
         if len(accounts) == 1:
-            def_account = accounts[0]
+            def_account = accounts[0][1]
     return def_account
 
 
